#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hOpenPGP
version:              2.10.1
visibility:           public
id:                   hOpenPGP-2.10.1-EzqnoVEhr3x3ZzPVxvxawt
key:                  hOpenPGP-2.10.1-EzqnoVEhr3x3ZzPVxvxawt
license:              MIT
copyright:            2012-2025  Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             https://salsa.debian.org/clint/hOpenPGP
synopsis:             native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)

category:             Codec, Data
abi:                  60b3beb9ea0c9f9c1a4da574e0733d80
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.SignatureQualities
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Codec.Encryption.OpenPGP.Version Data.Conduit.OpenPGP.Compression
    Data.Conduit.OpenPGP.Decrypt Data.Conduit.OpenPGP.Filter
    Data.Conduit.OpenPGP.Keyring Data.Conduit.OpenPGP.Keyring.Instances
    Data.Conduit.OpenPGP.Verify

hidden-modules:
    Codec.Encryption.OpenPGP.Internal
    Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
    Codec.Encryption.OpenPGP.Internal.Crypton
    Codec.Encryption.OpenPGP.Internal.HOBlockCipher
    Codec.Encryption.OpenPGP.Types.Internal.Base
    Codec.Encryption.OpenPGP.Types.Internal.CryptonNewtypes
    Codec.Encryption.OpenPGP.Types.Internal.PKITypes
    Codec.Encryption.OpenPGP.Types.Internal.PacketClass
    Codec.Encryption.OpenPGP.Types.Internal.Pkt
    Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
    Codec.Encryption.OpenPGP.Types.Internal.TK
    Codec.Encryption.OpenPGP.BlockCipher
    Codec.Encryption.OpenPGP.SerializeForSigs Paths_hOpenPGP

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hopenpgp
hs-libraries:         HShOpenPGP-2.10.1-EzqnoVEhr3x3ZzPVxvxawt
depends:
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0
    asn1-encoding-0.9.6-2z60VHsjZ4pGbNwjJKXafj
    attoparsec-0.14.4-5ZTCKiuMNMIGB4CMz6Pozo base-4.18.2.1
    base16-bytestring-1.0.2.0-AGwhh1Ev3mPCOOC4X0N9yh
    bifunctors-5.6.3-7CAuJJv50hD9g9RiiZ6n5a binary-0.8.9.1
    binary-conduit-1.3.1-GSmb2hMEPbSD7g6MHuLLTP bytestring-0.11.5.3
    bz2-1.0.1.1-Kw6N8r9KwAIAgG93gUGFdQ
    conduit-1.3.6.1-EmA1TJONA2cErpLghbE74P
    conduit-extra-1.3.8-HEUFd7W8CaD56AfUWO28c9 containers-0.6.7
    crypto-cipher-types-0.0.9-KR6SDml7aC01N7sg8RBO5C
    crypton-1.0.4-6JBp2GgpHz2CJQJZQym6mp
    errors-2.3.0-H1RR88QcqXUFBOykpBdlI6
    hashable-1.4.7.0-J2hh6EbI83E8iCoykKa5KL
    incremental-parser-0.5.1-G63fdzj7mmM5PYd51x8lsv
    ixset-typed-0.5.1.0-Gl4t8DWgtA7IctancypxE0
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8
    nettle-0.3.1.1-A0M1aIGFyuW7FI1LGOgmW3
    network-uri-2.6.4.2-EPISvuAciHNCNyhUbkgF33
    openpgp-asciiarmor-0.1.2-DS199aGT4zQHPOPhKzyNnL
    prettyprinter-1.7.1-1xxpbQWBfCkKy2RpQWmuRC
    resourcet-1.2.6-6UHT6wOZljkBsLcdnEKCgw
    split-0.2.5-Qi12kQYJr1H6TmSRWYEeS text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    zlib-0.7.1.0-DirfdD9kavL4Ly7NEYaRSf

haddock-interfaces:   /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html:         /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

